# About

This open source project was created by Michelle Weirathmueller at [Waveform 
Analytics, LLC](https://waveformanalytics.com).

If you find any issues, please report them on the [issues page](https://github.com/Waveform-Analytics/yooink/issues). We'd 
love it 
if you could include as much detail as possible, including any steps to 
reproduce the problem. Thank you!

If you have any questions, or if you'd like to contribute to this package, 
please contact [info@waveformanalytics.com](mailto:info@waveformanalytics.com).

[![WA logo](assets/wa-logo.png)](https://waveformanalytics.com)
